@@ -19,7 +19,7 @@
 #' @export
 #'
 remove_singletons <- function(data) {
-    if (class(data) == "GCalign") {
+    if (inherits(data, "GCalign")) {
         rt_col_name <-  data[["Logfile"]][["Call"]][["rt_col_name"]]
         data <- data[["aligned_list"]]
     } else if (is.list(data)) {
